/* vi:set wm=0 ai tabstop=4 shiftwidth=4: */

/*
 * sctl - Bearcat scanner control program
 * Copyright (C) 2001 Ian Johnston <reaper@muppetlabs.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include <stdio.h>
#include <stdlib.h>

#include "config.h"
#include "main.h"
#include "usage.h"

/***********************************************************************
 * determine which command they need help on
 ***********************************************************************/
void usage(int cmd)
{
	switch(cmd)
	{
		case C_ATT:
			usage_att();
			break;

		case C_DATA:
			usage_data();
			break;

		case C_DELAY:
			usage_delay();
			break;

		case C_DUMP:
			usage_dump();
			break;

		case C_ID_REPORT:
			usage_id_report();
			break;

		case C_LIGHT:
			usage_light();
			break;

		case C_LOAD:
			usage_load();
			break;

		case C_LOCKOUT:
			usage_lockout();
			break;

		case C_MEM:
			usage_mem();
			break;

		case C_MUTE:
			usage_mute();
			break;

		case C_SCAN:
			usage_scan();
			break;

		case C_SCAN_REPORT:
			usage_scan_report();
			break;

		case C_SEARCH:
			usage_search();
			break;

		case C_STATUS:
			usage_status();
			break;

		case C_TALKGROUP:
			usage_talkgroup();
			break;

		case C_VERSION:
			usage_version();
			break;

		default:
			fprintf(stderr, "Usage: sctl [-p port] [-m scannermodel] command options\n\n");
			fprintf(stderr, "Currently supported commands are:\n");
			fprintf(stderr, "  att       - sets or queries the attenuation feature [245][780]\n");
			fprintf(stderr, "  data      - sets or queries the data skip feature\n");
			fprintf(stderr, "  delay     - sets or queries delay setting\n");
			fprintf(stderr, "  dump      - downloads a memory bank from the scanner\n");
			fprintf(stderr, "  help      - displays a help message for a command\n");
			fprintf(stderr, "  idreport  - running report of talkgroup IDs\n");
			fprintf(stderr, "  light     - sets or queries lcd backlight [245][780]\n");
			fprintf(stderr, "  load      - uploads a saved memory bank to the scanner\n");
			fprintf(stderr, "  lockout   - sets or queries lockout setting\n");
			fprintf(stderr, "  mem       - sets or queries memory channel\n");
			fprintf(stderr, "  mute      - sets the current muting mode\n");
			fprintf(stderr, "  scan      - sets scanning mode\n");
			fprintf(stderr, "  sreport   - sets scan reporting mode\n");
			fprintf(stderr, "  search    - begins or continues a search\n");
			fprintf(stderr, "  status    - shows the current status of the scanner\n");
			fprintf(stderr, "  talkgroup - sets or queries the current talkgroup\n");
			fprintf(stderr, "  version   - displays version and licensing information\n\n");
			fprintf(stderr, "Commands need only be specified by enough letters to uniquely identify the\n");
			fprintf(stderr, "particular option.  Use \"sctl help cmdname\" to get more information on cmdname.\n");
			break;
	}

	exit(EXIT_SUCCESS);
}

/* do not delete this comment: column 100 */

/***********************************************************************
 ***********************************************************************/
void usage_att(void)
{
	fprintf(stderr, "Usage: sctl att [on|off]\n\n");
	fprintf(stderr, "This command sets or queries the RF attenuation feature.  If you are near an\n");
	fprintf(stderr, "unusually strong signal source, the scanner may stop repeatedly on that signal\n");
	fprintf(stderr, "and miss other transmissions.  When attenuation is enabled, all incoming\n");
	fprintf(stderr, "signals are reduced by 15 dB.\n");
	fprintf(stderr, "Specifying no option queries the current RF attenuation setting.\n\n");
	fprintf(stderr, "  on  - turn on attenuation (BC245XLT and BC780XLT only)\n");
	fprintf(stderr, "  off - turn off attenuation (BC245XLT and BC780XLT only)\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_data(void)
{
	fprintf(stderr, "Usage: sctl data [on|off]\n\n");
	fprintf(stderr, "This command tries to prevent the scanner from stopping on data signals and\n");
	fprintf(stderr, "unmodulated transmissions.  It isn't perfect, but it's better than nothing.\n");
	fprintf(stderr, "Specifying no option queries the current data skip setting.\n\n");
	fprintf(stderr, "  on  - turn on data skip\n");
	fprintf(stderr, "  off - turn off data skip\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_delay(void)
{
	fprintf(stderr, "Usage: sctl delay [on|off]\n\n");
	fprintf(stderr, "This command sets or queries the delay setting on the current channel.  Note\n");
	fprintf(stderr, "that delay can only be set or queried when the scanner is stopped on a channel,\n");
	fprintf(stderr, "and not when it's actively scanning.\n");
	fprintf(stderr, "Specifying no option queries the current delay setting.\n\n");
	fprintf(stderr, "  on  - turns on the delay setting for the current channel\n");
	fprintf(stderr, "  off - turns off the current channel's delay setting\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_dump(void)
{
	fprintf(stderr, "Usage: sctl dump bank [filename]\n\n");
	fprintf(stderr, "This command downloads a memory bank from the scanner, and saves it to a file\n");
	fprintf(stderr, "on disk.  The file can be later uploaded back to the scanner via the \"load\"\n");
	fprintf(stderr, "command.  If no filename is specified, data is sent to stdout.\n\n");
	fprintf(stderr, "  bank     - letter of the bank to download (A through J)\n");
	fprintf(stderr, "  filename - file to store the downloaded data in\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_id_report(void)
{
	fprintf(stderr, "Usage: sctl idreport\n\n");
	fprintf(stderr, "This command displays a running log of talkgroup ID reception begin and\n");
	fprintf(stderr, "end events.  These are reports of when a particular talkgroup ID begins\n");
	fprintf(stderr, "transmitting, and when it stops.  The report shows date and time,\n");
	fprintf(stderr, "whether reception is beginning or ending, talkgroup ID, and frequency\n");
	fprintf(stderr, "and signal strength on \"start\" events.\n\n");
	fprintf(stderr, "This command has no options.  Use ^C (ctrl-C) to break out of the report\n");
	fprintf(stderr, "mode.  Note that although you can engage this function regardless of the\n");
	fprintf(stderr, "scanner's mode, it won't report anything unless it's in either trunk\n");
	fprintf(stderr, "scan or trunk search mode.  This function has only been tested on the\n");
	fprintf(stderr, "895.\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_light(void)
{
	fprintf(stderr, "Usage: sctl light [on|off|auto|noauto]\n\n");
	fprintf(stderr, "This command sets or queries the LCD backlight.  It is also used to control the\n");
	fprintf(stderr, "\"autolight\" which will cause the display to light up for approximately five\n");
	fprintf(stderr, "seconds whenever the scanner hits an active frequency.\n");
	fprintf(stderr, "Specifying no option queries the current light status.\n\n");
	fprintf(stderr, "  on     - turns on the LCD backlight (BC245XLT and BC780XLT only)\n");
	fprintf(stderr, "  off    - turns off the LCD backlight (BC245XLT and BC780XLT only)\n");
	fprintf(stderr, "  auto   - turns on autolight (BC245XLT only)\n");
	fprintf(stderr, "  noauto - turns off autolight (BC245XLT only)\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_load(void)
{
	fprintf(stderr, "Usage: sctl load bank [filename]\n\n");
	fprintf(stderr, "This command uploads a saved memory bank file to the scanner.  The file must be\n");
	fprintf(stderr, "in the format output by the \"dump\" command (see format.txt) for it to be\n");
	fprintf(stderr, "understood.  If no filename is specified, data is read from stdin.\n\n");
	fprintf(stderr, "  bank     - letter of the bank to upload to (A through J)\n");
	fprintf(stderr, "  filename - file to upload the data from\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_lockout(void)
{
	fprintf(stderr, "Usage: sctl lockout [on|off]\n\n");
	fprintf(stderr, "The lockout command is used to set or check whether the current channel is\n");
	fprintf(stderr, "locked out or not.  The status can be changed whenever the scanner is stopped\n");
	fprintf(stderr, "on a channel, but can only be checked when the scanner is in manual mode.\n");
	fprintf(stderr, "Specifying no option queries the status.\n\n");
	fprintf(stderr, "  on  - turns on the lockout setting for the current channel\n");
	fprintf(stderr, "  off - turns off the current channel's lockout setting\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_mem(void)
{
	fprintf(stderr, "Usage: sctl mem [-f] [-q] [all|channel] [-c channels] [-s freq]\n\n");
	fprintf(stderr, "This command sets or queries the scanner's conventional (i.e. not talkgroups)\n");
	fprintf(stderr, "memory.\n");
	fprintf(stderr, "Specifying no option queries the current memory location.\n\n");
	fprintf(stderr, "  all         - specifying \"all\" lists all the memory contents\n");
	fprintf(stderr, "  channel     - specify a memory number between 1 and %d to switch to\n", MAXMEM);
	fprintf(stderr, "  -c channels - list multiple channels (in the format \"-c x-y\")\n");
	fprintf(stderr, "  -s freq     - sets the indicated memory to xxx.yyyy MHz\n");
	fprintf(stderr, "  -f          - forces the radio to manual mode if necessary\n");
	fprintf(stderr, "  -q          - only queries the given memory location, rather than setting\n");
	fprintf(stderr, "                that as the current memory.\n\n");
	fprintf(stderr, "Example: \"sctl mem 7 -s 150.5\" would set memory channel 7 to 150.5 MHz.\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_mute(void)
{
	fprintf(stderr, "Usage: sctl mute [off|normal|all]\n\n");
	fprintf(stderr, "This command sets or queries the speaker muting mode.\n");
	fprintf(stderr, "Specifying no option queries the current mute mode.\n\n");
	fprintf(stderr, "  off    - turn off speaker muting\n");
	fprintf(stderr, "  normal - turn on normal (squelch) speaker muting\n");
	fprintf(stderr, "  all    - mute speaker entirely\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_scan(void)
{
	fprintf(stderr, "Usage: sctl scan [-t] bank [bank bank ...]\n\n");
	fprintf(stderr, "This command sets the scanning mode, including which banks are being scanned.\n");
	fprintf(stderr, "BC245XLT users: bank 1 is equivalent to bank A, 2 would be B, etc.\n\n");
	fprintf(stderr, "  -t   - scan a trunking bank (note that only a one bank at a time\n");
	fprintf(stderr, "         can be trunk-scanned on the BC895XLT)\n");
	fprintf(stderr, "  bank - single letters (upper or lower case) separated by spaces to\n");
	fprintf(stderr, "         indicate a bank\n\n");
	fprintf(stderr, "Note: Be sure to separate the bank names by spaces, ex: sctl scan A B C\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_scan_report(void)
{
	fprintf(stderr, "Usage: sctl sreport bank [bank bank ...]\n\n");
	fprintf(stderr, "This command enables the scanning report mode.  Specify the banks to\n");
	fprintf(stderr, "scan, and the program enters an interactive mode where it reports on\n");
	fprintf(stderr, "the reception begin and end events.  This mode does not work for trunk \n");
	fprintf(stderr, "scanning, use the 'idreport' function for that.  Useful for logging.\n");
	fprintf(stderr, "BC245XLT users: bank 1 is equivalent to bank A, 2 would be B, etc.\n\n");
	fprintf(stderr, "  bank - single letters (upper or lower case) separated by spaces to\n");
	fprintf(stderr, "         indicate a bank\n\n");
	fprintf(stderr, "Note: Be sure to separate the bank names by spaces, ex: sctl sreport A B C\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_search(void)
{
	fprintf(stderr, "Usage: search [freq1] [freq2]\n\n");
	fprintf(stderr, "This command begins or continues a frequency range search.\n\n");
	fprintf(stderr, "  freq1 - sets one limit to the searched frequency range, in MHz\n");
	fprintf(stderr, "  freq2 - sets the other limit to the searched frequency range, in MHz\n\n");
	fprintf(stderr, "Example: \"sctl search 902 928\" would set the scanner to search between 902 and\n");
	fprintf(stderr, "\t928 MHz.  If the search stopped on a frequency you could type \"sctl\n");
	fprintf(stderr, "\tsearch\" to resume the same search.\n");
}
	
/***********************************************************************
 ***********************************************************************/
void usage_status(void)
{
	fprintf(stderr, "Usage: sctl status\n\n");
	fprintf(stderr, "This command shows the current status of the radio, including the mode\n");
	fprintf(stderr, "(scanning, trunktracking, manual mode, etc.) and possibly more information,\n");
	fprintf(stderr, "depending upon which mode it's in.  There are no options to this command.\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_talkgroup(void)
{
	fprintf(stderr, "Usage: sctl talkgroup [all|memory] [bank] [-s talkgroup]\n\n");
	fprintf(stderr, "The talkgroup command will display the talkgroup to which the scanner is\n");
	fprintf(stderr, "currently listening, or optionally set a talkgroup to listen to.\n");
	fprintf(stderr, "Specifying no options queries the current talkgroup.\n\n");
	fprintf(stderr, "  all          - specifying \"all\" lists all talkgroup memories\n");
	fprintf(stderr, "  memory       - (in the form A0 or E6) switch to that ID location\n");
	fprintf(stderr, "  bank         - specify bank id (if not already in trunk mode)\n");
	fprintf(stderr, "  -s talkgroup - set the specified memory to talkgroup (0 means \"empty\")\n\n");
	fprintf(stderr, "Example: \"sctl talkgroup E6 F -s 1775\" would set memory location E6 in bank F\n");
	fprintf(stderr, "\tto talkgroup number 1775.  You must specify a bank letter if not in\n");
	fprintf(stderr, "\ttrunk mode.  Specifying a bank letter in trunk mode will switch to that\n");
	fprintf(stderr, "\ttrunk bank.\n");
}

/***********************************************************************
 ***********************************************************************/
void usage_version(void)
{
	fprintf(stderr, "Usage: version\n\n");
	fprintf(stderr, "This command will display version information for your scanner and for sctl.\n");
	fprintf(stderr, "Please include the output of this command with any bug reports you submit.\n\n");
	fprintf(stderr, "Note: This command will not return scanner information on the BC895XLT.\n");
}
